@@ -1,9 +1,9 @@
 from sqlalchemy_api_handler.api_errors import ApiErrors
 from sqlalchemy_api_handler.api_handler import ApiHandler
 from sqlalchemy_api_handler.serialization.as_dict import as_dict
+from sqlalchemy_api_handler.utils.get_result import get_result
 from sqlalchemy_api_handler.utils.human_ids import humanize, dehumanize
-from sqlalchemy_api_handler.utils.listify import listify
 from sqlalchemy_api_handler.utils.load_or_404 import load_or_404
 from sqlalchemy_api_handler.utils.logger import logger
 
-__version__ = "0.1.10"
+__version__ = "0.2.2"
